@@ -591,12 +591,12 @@ int cmd_inspect_dump_super(int argc, char **argv)
 			all = 0;
 			break;
 		default:
-			usage(cmd_inspect_dump_super_usage);
+			usage_unknown_option(cmd_inspect_dump_super_usage, argv);
 		}
 	}
 
 	if (check_argc_min(argc - optind, 1))
-		usage(cmd_inspect_dump_super_usage);
+		return 1;
 
 	for (i = optind; i < argc; i++) {
 		filename = argv[i];
